Enumeration
IdeDebuggerBreakMode
Members
-
IDE_DEBUGGER_BREAK_NONE -
No breakpoint is set.
- Value:
0 - Available since: 50
- Value:
-
IDE_DEBUGGER_BREAK_BREAKPOINT -
A simple breakpoint that stops the debugger when reaching a given location.
- Value:
1 - Available since: 50
- Value:
-
IDE_DEBUGGER_BREAK_COUNTPOINT -
A counter that is incremented when the debugger reaches a breakpoint.
- Value:
2 - Available since: 50
- Value:
-
IDE_DEBUGGER_BREAK_WATCHPOINT -
A breakpoint that is conditional on the specification matching.
- Value:
3 - Available since: 50
- Value: